diff --git a/dumux/porousmediumflow/1p/model.hh b/dumux/porousmediumflow/1p/model.hh
index 4d1cc3e27364b1bd92b52ec7f8f8f8887c3b2452..bb0dbffcbdfa6cd4fe5f418370b88987862c51e6 100644
--- a/dumux/porousmediumflow/1p/model.hh
+++ b/dumux/porousmediumflow/1p/model.hh
@@ -14,7 +14,7 @@
  *
  * Furthermore, it solves the mass continuity equation
  * \f[
- \phi \frac{\partial \varrho}{\partial t} + \nabla \cdot \left\lbrace
+ \frac{\partial (\phi \varrho) }{\partial t} + \nabla \cdot \left\lbrace
  - \varrho \frac{\textbf K}{\mu} \left( \nabla  p -\varrho {\textbf g} \right) \right\rbrace = q,
  * \f]
 * where:
diff --git a/dumux/porousmediumflow/1pnc/model.hh b/dumux/porousmediumflow/1pnc/model.hh
index 4ebdeb35f1eb58a4130adb77fb834c6a59a7d51e..58024ae384fc90855510ff4dfb16b7669ee6a7bb 100644
--- a/dumux/porousmediumflow/1pnc/model.hh
+++ b/dumux/porousmediumflow/1pnc/model.hh
@@ -15,14 +15,14 @@
  * Gravity can be enabled or disabled via the property system.
  * By inserting Darcy's law into the continuity equation, one gets
  \f[
- \phi\frac{\partial \varrho}{\partial t} - \nabla \cdot \left\{
+ \frac{\partial (\phi \varrho) }{\partial t} - \nabla \cdot \left\{
    \varrho \frac{\textbf K}{\mu}  \left(\nabla  p - \varrho {\textbf g} \right)
  \right\} = q.
  \f]
  *
  * The transport of the components \f$\kappa \in \{ w, a, ... \}\f$ is described by the following equation:
  \f[
- \phi \frac{ \partial \varrho X^\kappa}{\partial t}
+ \frac{ \partial (\phi \varrho X^\kappa) }{\partial t}
  - \nabla \cdot \left\lbrace \varrho X^\kappa \frac{{\textbf K}}{\mu} \left( \nabla  p -
  \varrho {\textbf g} \right)
  + \varrho D^\kappa_\text{pm} \nabla X^\kappa \right\rbrace = q,
@@ -36,7 +36,7 @@
  * * \f$ \mu \f$ represents the dynamic viscosity,
  * * \f$ p \f$ is the pressure,
  * * \f$ \textbf{g} \f$ is the gravitational acceleration vector,
- * * \f$ {\bf D_{pm}^\kappa} \f$ is the diffusivity in the porous medium,
+ * * \f$ {\bf D_{pm}^\kappa} \f$ is the effective diffusivity in the porous medium,
  * * and \f$ q \f$ is a source or sink term.
  *
  * The model is able to use either mole or mass fractions. The property useMoles can be set to either true or false in the
diff --git a/dumux/porousmediumflow/1pncmin/model.hh b/dumux/porousmediumflow/1pncmin/model.hh
index 5c1bf5a51d8aa999d7847d32634366f2f7074f08..ffee022ef43f1192064dfde6485b6e96c9db1dae 100644
--- a/dumux/porousmediumflow/1pncmin/model.hh
+++ b/dumux/porousmediumflow/1pncmin/model.hh
@@ -18,7 +18,7 @@
 * By inserting Darcy's law into the equations for the conservation of the
 * components, one gets one transport equation for each component,
 * \f[
- \frac{\partial ( \varrho_f X^\kappa \phi  )}
+ \frac{\partial ( \phi \varrho_f X^\kappa )}
 {\partial t} -  \nabla \cdot \left\{ \varrho_f X^\kappa
 \frac{k_{r}}{\mu} \mathbf{K}
 (\nabla  p - \varrho_{f}  \mathbf{g}) \right\}
@@ -34,7 +34,7 @@
 * * \f$ \mathbf{K} \f$ is the intrinsic permeability tensor,
 * * \f$ p \f$ is the pressure,
 * * \f$ \mathbf{g} \f$ is the gravitational acceleration vector,
-* * \f$ {\bf D_{pm}^\kappa} \f$ is the diffusivity in the porous medium,
+* * \f$ {\bf D_{pm}^\kappa} \f$ is the effective diffusivity in the porous medium,
 * * \f$ q_\kappa \f$ is a source or sink term.
 *
 * The solid or mineral phases are assumed to consist of a single component.
diff --git a/dumux/porousmediumflow/2p/model.hh b/dumux/porousmediumflow/2p/model.hh
index fe7adb6fbe1f6a3f124a9990a87d97e9d5b8d742..791e30e077125648fa18ebc08bd2a1dacaaa6343 100644
--- a/dumux/porousmediumflow/2p/model.hh
+++ b/dumux/porousmediumflow/2p/model.hh
@@ -17,7 +17,7 @@
  * By inserting Darcy's law into the equations for the conservation of the
  * phase mass, one gets
  \f[
- \phi \frac{\partial \varrho_\alpha S_\alpha}{\partial t}
+ \frac{\partial (\phi \varrho_\alpha S_\alpha) }{\partial t}
  -
  \nabla \cdot \left\{
  \varrho_\alpha \frac{k_{r\alpha}}{\mu_\alpha} \mathbf{K} \left(\nabla  p_\alpha - \varrho_{\alpha} \mathbf{g} \right)
diff --git a/dumux/porousmediumflow/2p1c/model.hh b/dumux/porousmediumflow/2p1c/model.hh
index a34e4799f0726394a6abd2e966d880537c16e95f..58bf838168c8add348afb89f5908d4f499eebc41 100644
--- a/dumux/porousmediumflow/2p1c/model.hh
+++ b/dumux/porousmediumflow/2p1c/model.hh
@@ -23,7 +23,7 @@
  * By inserting Darcy's law into the equations for the conservation of the
  * phase mass, one gets
  \f[
-\phi \frac{\partial\ \sum_\alpha (\rho_\alpha S_\alpha)}{\partial t} \\-\sum \limits_ \alpha \nabla \cdot \left \{\rho_\alpha \frac{k_{r\alpha}}{\mu_\alpha}
+\frac{\partial\ \sum_\alpha (\phi \rho_\alpha S_\alpha)}{\partial t} \\-\sum \limits_ \alpha \nabla \cdot \left \{\rho_\alpha \frac{k_{r\alpha}}{\mu_\alpha}
 \mathbf{K} (\nabla p_\alpha - \rho_\alpha \mathbf{g}) \right \} -q^w =0,
  \f]
  * where:
diff --git a/dumux/porousmediumflow/2p2c/model.hh b/dumux/porousmediumflow/2p2c/model.hh
index e50ef401f24c4de403306ef64c01d98b72465838..da4df68d4d9744df1d4ccd642a9e41760fa1bef9 100644
--- a/dumux/porousmediumflow/2p2c/model.hh
+++ b/dumux/porousmediumflow/2p2c/model.hh
@@ -16,14 +16,14 @@
  * The governing equations are the mass or the mole conservation equations of the two components,
  * depending on the property <tt>UseMoles</tt>. The mass balance equations are given as
  * \f[
-   \phi \frac{\partial (\sum_\alpha \rho_\alpha X_\alpha^\kappa S_\alpha)}{\partial t}
+   \frac{\partial (\sum_\alpha \phi \rho_\alpha X_\alpha^\kappa S_\alpha)}{\partial t}
    - \sum_\alpha \nabla \cdot \left\{ \rho_\alpha X_\alpha^\kappa v_\alpha \right\}
    - \sum_\alpha \nabla \cdot \mathbf{F}_{\mathrm{diff, mass}, \alpha}^\kappa
    - \sum_\alpha q_\alpha^\kappa = 0 \qquad \kappa \in \{\kappa_w, \kappa_n\} \, , \alpha \in \{w, n\}.
    \f]
  * The mole balance is given as
  * \f[
-   \phi \frac{\partial (\sum_\alpha \varrho_{m, \alpha} x_\alpha^\kappa S_\alpha)}{\partial t}
+   \frac{\partial (\sum_\alpha \phi \varrho_{m, \alpha} x_\alpha^\kappa S_\alpha)}{\partial t}
    + \sum_\alpha \nabla \cdot \left\{ \varrho_{m, \alpha} x_\alpha^\kappa v_\alpha \right\}
    + \sum_\alpha \nabla \cdot \mathbf{F}_{\mathrm{diff, mole}, \alpha}^\kappa
    - \sum_\alpha q_\alpha^\kappa = 0 \qquad \kappa \in \{\kappa_w, \kappa_n\} \, , \alpha \in \{w, n\},
diff --git a/dumux/porousmediumflow/2pnc/model.hh b/dumux/porousmediumflow/2pnc/model.hh
index 85d42a3c10e7ab8648b80ec3a4b8b6c723570582..8503e967d7580b6f95edf276ac4d888a5cb39500 100644
--- a/dumux/porousmediumflow/2pnc/model.hh
+++ b/dumux/porousmediumflow/2pnc/model.hh
@@ -20,7 +20,7 @@
  * By inserting Darcy's law into the equations for the conservation of the
  * components, one gets one transport equation for each component,
  * \f{eqnarray*}{
- * && \frac{\partial (\sum_\alpha \varrho_\alpha X_\alpha^\kappa \phi S_\alpha )}
+ * && \frac{\partial (\sum_\alpha \phi \varrho_\alpha X_\alpha^\kappa S_\alpha )}
  * {\partial t}
  * - \sum_\alpha  \nabla \cdot \left\{ \varrho_\alpha X_\alpha^\kappa
  * \frac{k_{r\alpha}}{\mu_\alpha} \mathbf{K}
diff --git a/dumux/porousmediumflow/2pncmin/model.hh b/dumux/porousmediumflow/2pncmin/model.hh
index a10644a7cd59882c13e3d7ed7b773b0dfc55dcbe..f78816b71c2032268f5c58682679a6c822d14a71 100644
--- a/dumux/porousmediumflow/2pncmin/model.hh
+++ b/dumux/porousmediumflow/2pncmin/model.hh
@@ -20,7 +20,7 @@
  * By inserting Darcy's law into the equations for the conservation of the
  * components, one gets one transport equation for each component,
  * \f{eqnarray*}{
- * && \frac{\partial (\sum_\alpha \varrho_\alpha X_\alpha^\kappa \phi S_\alpha )}
+ * && \frac{\partial (\sum_\alpha \phi \varrho_\alpha X_\alpha^\kappa S_\alpha )}
  * {\partial t}
  * - \sum_\alpha  \nabla \cdot \left\{ \varrho_\alpha X_\alpha^\kappa
  * \frac{k_{r\alpha}}{\mu_\alpha} \mathbf{K}
diff --git a/dumux/porousmediumflow/3p/model.hh b/dumux/porousmediumflow/3p/model.hh
index d2fc6cd27ac0b2885811c3a1f78e6dd6165d0fac..68c9388350e25de4a3e4d0481d0afd048c7c89a7 100644
--- a/dumux/porousmediumflow/3p/model.hh
+++ b/dumux/porousmediumflow/3p/model.hh
@@ -18,7 +18,7 @@
  * By inserting Darcy's law into the equations for the conservation
  * of the phase mass, one gets
  \f[
- \phi \frac{\partial \varrho_\alpha S_\alpha}{\partial t}
+ \frac{\partial (\phi \varrho_\alpha S_\alpha )}{\partial t}
  -
  \nabla \cdot \left\{
  \varrho_\alpha \frac{k_{r\alpha}}{\mu_\alpha} \mathbf{K} \left(\nabla  p_\alpha - \varrho_{\alpha} \mathbf{g} \right)
diff --git a/dumux/porousmediumflow/3p3c/model.hh b/dumux/porousmediumflow/3p3c/model.hh
index b41ba06e32d17a3d415a49b61d1a490c1ab21031..a030d7c38311e6d3c6828e720ec6fdb4de9a7f0a 100644
--- a/dumux/porousmediumflow/3p3c/model.hh
+++ b/dumux/porousmediumflow/3p3c/model.hh
@@ -19,14 +19,14 @@
  * By inserting Darcy's law into the equations for the conservation of the
  * components, one transport equation for each component is obtained as
  * \f{eqnarray*}
- && \phi \frac{\partial (\sum_\alpha \varrho_{\alpha,mol} x_\alpha^\kappa
+ && \frac{\partial (\sum_\alpha \phi \varrho_{\alpha,mol} x_\alpha^\kappa
  S_\alpha )}{\partial t}
  - \sum\limits_\alpha \nabla \cdot \left\{ \frac{k_{r\alpha}}{\mu_\alpha}
  \varrho_{\alpha,mol} x_\alpha^\kappa \mathbf{K}
  (\nabla  p_\alpha - \varrho_{\alpha,mass} \mathbf{g}) \right\}
  \nonumber \\
  \nonumber \\
- && - \sum\limits_\alpha \nabla \cdot \left\{ D_\text{pm}^\kappa \frac{1}{M_{\kappa}} \varrho_{\alpha}
+ && - \sum\limits_\alpha \nabla \cdot \left\{ D_{\alpha, \text{pm}}^\kappa \frac{1}{M_{\kappa}} \varrho_{\alpha}
  \nabla X^\kappa_{\alpha} \right\}
  - q^\kappa = 0 \qquad \forall \kappa , \; \forall \alpha,
  \f}
@@ -37,7 +37,7 @@
  * * \f$ X_\alpha^\kappa \f$ is the mass fraction of component \f$ \kappa \f$ in phase  \f$ \alpha \f$,
  * * \f$ x_\alpha^\kappa \f$ is the mole fraction of component \f$ \kappa \f$ in phase    \f$ \alpha \f$,
  * * \f$ v_\alpha \f$ is the velocity of phase \f$ \alpha \f$,
- * * \f$ {\bf D_{\alpha, pm}^\kappa} \f$ is the diffusivity of component \f$ \kappa \f$  in phase \f$ \alpha \f$,
+ * * \f$ D_{\alpha, \text{pm}}^\kappa \f$ is the effective diffusivity of component \f$ \kappa \f$  in phase \f$ \alpha \f$,
  * * \f$ M_\kappa \f$ is the molar mass of component \f$ \kappa \f$
  * * \f$ q_\alpha^\kappa \f$ is a source or sink term.
  *
diff --git a/dumux/porousmediumflow/3pwateroil/model.hh b/dumux/porousmediumflow/3pwateroil/model.hh
index 02806c10bdd4bc4c6901cd280a07a49424495301..5d81b1084f37f7fd37dc374c77add4140940a9ec 100644
--- a/dumux/porousmediumflow/3pwateroil/model.hh
+++ b/dumux/porousmediumflow/3pwateroil/model.hh
@@ -20,14 +20,14 @@
  * By inserting Darcy's law into the equations for the conservation of the
  * components, one transport equation for each component is obtained as
  * \f{eqnarray*}
- && \phi \frac{\partial (\sum_\alpha \varrho_\alpha X_\alpha^\kappa
+ && \frac{\partial (\sum_\alpha \phi \varrho_\alpha X_\alpha^\kappa
  S_\alpha )}{\partial t}
  - \sum\limits_\alpha \nabla \cdot \left\{ \frac{k_{r\alpha}}{\mu_\alpha}
  \varrho_\alpha x_\alpha^\kappa \mathbf{K}
  (\nabla  p_\alpha - \varrho_\alpha \mathbf{g}) \right\}
  \nonumber \\
  \nonumber \\
- && - \sum\limits_\alpha \nabla \cdot \left\{ D_\text{pm}^\kappa \varrho_\alpha \frac{1}{M_\kappa}
+ && - \sum\limits_\alpha \nabla \cdot \left\{ D_{\alpha, \text{pm}}^\kappa \varrho_\alpha \frac{1}{M_\kappa}
  \nabla X^\kappa_{\alpha} \right\}
  - q^\kappa = 0 \qquad \forall \kappa , \; \forall \alpha,
  \f}
@@ -39,7 +39,7 @@
  * * \f$ X_\alpha^\kappa \f$ is the mass fraction of component \f$ \kappa \f$ in phase  \f$ \alpha \f$,
  * * \f$ x_\alpha^\kappa \f$ is the mole fraction of component \f$ \kappa \f$ in phase    \f$ \alpha \f$,
  * * \f$ v_\alpha \f$ is the velocity of phase \f$ \alpha \f$,
- * * \f$ {\bf D_{\alpha, pm}^\kappa} \f$ is the diffusivity of component \f$ \kappa \f$  in phase \f$ \alpha \f$,
+ * * \f$ D_{\alpha, \text{pm}}^\kappa \f$ is the effective diffusivity of component \f$ \kappa \f$  in phase \f$ \alpha \f$,
  * * \f$ M_\kappa \f$ is the molar mass of component \f$ \kappa \f$
  * * \f$ q_\alpha^\kappa \f$ is a source or sink term.
  *
diff --git a/dumux/porousmediumflow/mpnc/model.hh b/dumux/porousmediumflow/mpnc/model.hh
index f3ea0e7504450c50134441a7a20471e8b8b5b5c0..8181f0af7fa925e15f42bf7a2afdc6c2b6c7d3f4 100644
--- a/dumux/porousmediumflow/mpnc/model.hh
+++ b/dumux/porousmediumflow/mpnc/model.hh
@@ -25,7 +25,7 @@
  * each component \f$\kappa\f$,
  * \f[
  \sum_{\kappa} \left(
-    \phi \frac{\partial \left(\varrho_\alpha x_\alpha^\kappa S_\alpha\right)}{\partial t}
+    \frac{\partial \left(\phi \varrho_\alpha x_\alpha^\kappa S_\alpha\right)}{\partial t}
     +
     \mathrm{div}\;
     \left\{
diff --git a/dumux/porousmediumflow/nonisothermal/model.hh b/dumux/porousmediumflow/nonisothermal/model.hh
index 024e76c4d1539e21929fef22b43dae05962f1b8a..294b58497509d6769ddf12c8d955baf481b260c2 100644
--- a/dumux/porousmediumflow/nonisothermal/model.hh
+++ b/dumux/porousmediumflow/nonisothermal/model.hh
@@ -19,9 +19,9 @@
  * results in one energy conservation equation for the porous solid
  * matrix and the fluids,
  \f{align*}{
- \phi \frac{\partial \sum_\alpha \varrho_\alpha u_\alpha S_\alpha}{\partial t}
+ \frac{\partial (\sum_\alpha \phi \varrho_\alpha u_\alpha S_\alpha )}{\partial t}
  & +
- \left( 1 - \phi \right) \frac{\partial (\varrho_s c_s T)}{\partial t}
+ \frac{\partial \left((\left( 1 - \phi \right) \varrho_s c_s T\right)}{\partial t}
  -
  \sum_\alpha \nabla \cdot
  \left\{
diff --git a/dumux/porousmediumflow/richardsextended/model.hh b/dumux/porousmediumflow/richardsextended/model.hh
index f3e0749cf64507dd7c3ad02169ac8c34094dca99..49922b3f1a6c4df0ec12feeb97c96f3f01019929 100644
--- a/dumux/porousmediumflow/richardsextended/model.hh
+++ b/dumux/porousmediumflow/richardsextended/model.hh
@@ -10,11 +10,11 @@
  * \brief This model implements a variant of the extended Richards'
  *        equation for quasi-twophase flow (see e.g. Vanderborght et al. 2017).
  *
- * In the unsaturated zone, Richards' equation
+ * The extended Richards' equation
  \f[
- \frac{\partial\;\phi S_w \varrho_w}{\partial t}
+ \frac{\partial (\phi S_w \varrho_w) }{\partial t}
  +
- \frac{\partial\;\phi (1-S_w)\varrho_n X_n^w}{\partial t}
+ \frac{\partial (\phi (1-S_w)\varrho_n X_n^w ) }{\partial t}
  -
  \nabla \cdot \left\lbrace
  \varrho_w \frac{k_{rw}}{\mu_w} \; \mathbf{K} \;
@@ -37,63 +37,14 @@
  * * \f$ \mathbf{K} \f$ is the intrinsic permeability tensor,
  * * \f$ p_w \f$ is the pressure of the wetting phase,
  * * \f$ \mathbf{g} \f$ is the gravitational acceleration vector,
- * * \f$ \bf D_{n,pm}^{w} \f$ is the diffusivity of water in the non-wetting phase,
+ * * \f$ \bf D_{n,pm}^{w} \f$ is the effective diffusivity of water in the non-wetting phase,
  * * \f$ X_n^w \f$ is the mass fraction of water in the non-wetting phase,
  * * \f$ q_w \f$ is a source or sink term in the wetting phase,
  *
- * is frequently used to
- * approximate the water distribution above the groundwater level.
- *
- * It can be derived from the two-phase equations, i.e.
- \f[
- \phi\frac{\partial S_\alpha \varrho_\alpha}{\partial t}
- -
- \nabla \cdot \left\lbrace
- \varrho_\alpha \frac{k_{r\alpha}}{\mu_\alpha}\; \mathbf{K} \;
- \left( \text{\nabla}
- p_\alpha - \varrho_\alpha \textbf{g}
- \right)
- \right\rbrace
- =
- q_\alpha,
- \f]
- *
- * where:
- * * \f$ \phi \f$ is the porosity of the porous medium,
- * * \f$ S_\alpha \f$ represents the saturation of phase \f$ \alpha \f$,
- * * \f$ \varrho_\alpha \f$ is the mass density of phase \f$ \alpha \f$,
- * * \f$ k_{r\alpha} \f$ is the relative permeability of phase \f$ \alpha \f$,
- * * \f$ \mu_\alpha \f$ is the dynamic viscosity of phase \f$ \alpha \f$,
- * * \f$ \mathbf{K} \f$ is the intrinsic permeability tensor,
- * * \f$ p_\alpha \f$ is the pressure of phase \f$ \alpha \f$,
- * * \f$ \mathbf{g} \f$ is the gravitational acceleration vector,
- * * \f$ q_\alpha \f$ is a source or sink term.
- *
- * In contrast to the full two-phase model, the Richards model assumes
- * gas as the nonwetting fluid and that it exhibits a much lower
- * viscosity than the (liquid) wetting phase. (For example at
- * atmospheric pressure and at room temperature, the viscosity of air
- * is only about \f$1\%\f$ of the viscosity of liquid water.) As a
- * consequence, the \f$\frac{k_{r\alpha}}{\mu_\alpha}\f$ term
- * typically is much larger for the gas phase than for the wetting
- * phase. For this reason, the Richards model assumes that
- * \f$\frac{k_{rn}}{\mu_n}\f$ is infinitely large. This implies that
- * the pressure of the gas phase is equivalent to the static pressure
- * distribution and that therefore, mass conservation only needs to be
- * considered for the wetting phase.
- *
- * The model thus chooses the absolute pressure of the wetting phase
- * \f$p_w\f$ as its only primary variable. The wetting phase
- * saturation is calculated using the inverse of the capillary
- * pressure, i.e.
- \f[
- S_w = p_c^{-1}(p_n - p_w)
- \f]
- * holds, where \f$p_n\f$ is a given reference pressure. Nota bene,
- * that the last step is assumes that the capillary
- * pressure-saturation curve can be uniquely inverted, so it is not
- * possible to set the capillary pressure to zero when using the
- * Richards model!
+ * additionally models water vapor diffusion in the gas phase.
+ * The model is derived based on the two-phase flow equations
+ * based on the assumption that the gas phase does not move but
+ * and remains at constant pressure.
  */
 
 #ifndef DUMUX_RICHARDSEXTENDED_MODEL_HH
diff --git a/dumux/porousmediumflow/richardsnc/model.hh b/dumux/porousmediumflow/richardsnc/model.hh
index 737f318cd671b74bdb660bf744cc032769334485..813666b637968139d80e210a8b5ee39f2dd35810 100644
--- a/dumux/porousmediumflow/richardsnc/model.hh
+++ b/dumux/porousmediumflow/richardsnc/model.hh
@@ -10,7 +10,8 @@
  * \brief Base class for all models which use the Richards,
  *        n-component fully implicit model.
  *
- * In the unsaturated zone, Richards' equation
+ * This extension of Richards' equation, allows for
+ * the wetting phase to consist of multiple components:
  *\f{eqnarray*}
  && \frac{\partial (\sum_w \varrho_w X_w^\kappa \phi S_w )}
  {\partial t}
@@ -31,38 +32,9 @@
  * * \f$ \mathbf{K} \f$ is the intrinsic permeability tensor,
  * * \f$ p_w \f$ is the pressure of the wetting phase,
  * * \f$ \mathbf{g} \f$ is the gravitational acceleration vector,
- * * \f$ \bf D_{w,pm}^{k} \f$ is the diffusivity of component \f$ \kappa \f$ in the wetting phase,
+ * * \f$ \bf D_{w,pm}^{k} \f$ is the effective diffusivity of component \f$ \kappa \f$ in the wetting phase,
  * * \f$ X_w^k \f$ is the mass fraction of component \f$ \kappa \f$ in the wetting phase,
- * * \f$ q_w \f$ is a source or sink term in the wetting phase,
- *
- * is frequently used to
- * approximate the water distribution above the groundwater level.
- *
- * In contrast to the full two-phase model, the Richards model assumes
- * gas as the nonwetting fluid and that it exhibits a much lower
- * viscosity than the (liquid) wetting phase. (For example at
- * atmospheric pressure and at room temperature, the viscosity of air
- * is only about \f$1\%\f$ of the viscosity of liquid water.) As a
- * consequence, the \f$\frac{k_{r\alpha}}{\mu_\alpha}\f$ term
- * typically is much larger for the gas phase than for the wetting
- * phase. For this reason, the Richards model assumes that
- * \f$\frac{k_{rn}}{\mu_n}\f$ is infinitely large. This implies that
- * the pressure of the gas phase is equivalent to the static pressure
- * distribution and that therefore, mass conservation only needs to be
- * considered for the wetting phase.
- *
- * The model thus chooses the absolute pressure of the wetting phase
- * \f$p_w\f$ as its only primary variable. The wetting phase
- * saturation is calculated using the inverse of the capillary
- * pressure, i.e.
- \f[
- S_w = p_c^{-1}(p_n - p_w)
- \f]
- * holds, where \f$p_n\f$ is a given reference pressure. Nota bene,
- * that the last step is assumes that the capillary
- * pressure-saturation curve can be uniquely inverted, so it is not
- * possible to set the capillary pressure to zero when using the
- * Richards model!
+ * * \f$ q_w \f$ is a source or sink term in the wetting phase.
  */
 
 #ifndef DUMUX_RICHARDSNC_MODEL_HH
diff --git a/dumux/porousmediumflow/solidenergy/model.hh b/dumux/porousmediumflow/solidenergy/model.hh
index cffb23ec70cd371ffce623934f5a5c0f7003cb88..877618f032901416795d2153895ccdd556405a76 100644
--- a/dumux/porousmediumflow/solidenergy/model.hh
+++ b/dumux/porousmediumflow/solidenergy/model.hh
@@ -12,7 +12,7 @@
  *
  * The energy balance is described by the following equation:
  \f[
-   \frac{ \partial n c_p \varrho T}{\partial t}
+   \frac{ \partial (n c_p \varrho T)}{\partial t}
    - \nabla \cdot \left\lbrace \lambda_\text{pm} \nabla T \right\rbrace = q,
  \f]
  * where:
diff --git a/dumux/porousmediumflow/tracer/model.hh b/dumux/porousmediumflow/tracer/model.hh
index 4c4efa24f10cbfd073900cb243ac1c66a49f0dc8..98a6c14ed863e2e8061b90a45fb7b449cfb9327c 100644
--- a/dumux/porousmediumflow/tracer/model.hh
+++ b/dumux/porousmediumflow/tracer/model.hh
@@ -19,7 +19,7 @@
  *
  * The transport of the components \f$\kappa \in \{ a, b, c, ... \}\f$ is described by the following equation:
  \f[
- \phi \frac{ \partial \varrho X^\kappa}{\partial t}
+ \frac{ \partial (\phi \varrho X^\kappa)}{\partial t}
  - \nabla \cdot \left\lbrace \varrho X^\kappa {\textbf v_f}
  + \varrho D^\kappa_\text{pm} \nabla X^\kappa \right\rbrace = q,
  \f]
diff --git a/dumux/porousmediumflow/richards/model.hh b/dumux/porousmediumflow/richards/model.hh
index 01efffdcb72d37514b94b3fde447aea7d208ff4b..00bdb7d97a456a4733540228fbf7e92a56e00e20 100644
--- a/dumux/porousmediumflow/richards/model.hh
+++ b/dumux/porousmediumflow/richards/model.hh
@@ -11,8 +11,10 @@
  *        equation for quasi-twophase flow.
  *
  * In the unsaturated zone, Richards' equation
+ * is frequently used to approximate the water distribution
+ * above the groundwater level (in the unsaturated zone):
  \f[
- \frac{\partial\;\phi S_w \varrho_w}{\partial t}
+ \frac{\partial (\phi S_w \varrho_w)}{\partial t}
  -
  \nabla \cdot \left\lbrace
  \varrho_w \frac{k_{rw}}{\mu_w} \; \mathbf{K} \;
@@ -24,43 +26,27 @@
  q_w,
  \f]
  *
- * is frequently used to
- * approximate the water distribution above the groundwater level.
- *
- * It can be derived from the two-phase equations, i.e.
- \f[
- \phi\frac{\partial S_\alpha \varrho_\alpha}{\partial t}
- -
- \nabla \cdot \left\lbrace
- \varrho_\alpha \frac{k_{r\alpha}}{\mu_\alpha}\; \mathbf{K} \;
- \left(\nabla
- p_\alpha - \varrho_\alpha \textbf{g}
- \right)
- \right\rbrace
- =
- q_\alpha,
- \f]
- *
  * where:
  * * \f$ \phi \f$ is the porosity of the porous medium,
- * * \f$ S_\alpha \f$ represents the saturation of phase \f$ \alpha \f$,
- * * \f$ \varrho_\alpha \f$ is the mass density of phase \f$ \alpha \f$,
- * * \f$ k_{r\alpha} \f$ is the relative permeability of phase \f$ \alpha \f$,
- * * \f$ \mu_\alpha \f$ is the dynamic viscosity of phase \f$ \alpha \f$,
+ * * \f$ S_w \f$ represents the water saturation,
+ * * \f$ \varrho_w \f$ is the water density,
+ * * \f$ k_{rw} \f$ is the relative permeability of the water phase,
+ * * \f$ \mu_w \f$ is the dynamic viscosity of the water phase,
  * * \f$ \mathbf{K} \f$ is the intrinsic permeability tensor,
- * * \f$ p_\alpha \f$ is the pressure of phase \f$ \alpha \f$,
+ * * \f$ p_w \f$ is the liquid water pressure,
  * * \f$ \mathbf{g} \f$ is the gravitational acceleration vector,
- * * \f$ q_\alpha \f$ is a source or sink term.
+ * * \f$ q_w \f$ is a source or sink term.
  *
+ * It can be derived from the two-phase flow equations.
  * In contrast to the full two-phase model, the Richards model assumes
  * gas as the nonwetting fluid and that it exhibits a much lower
  * viscosity than the (liquid) wetting phase. (For example at
  * atmospheric pressure and at room temperature, the viscosity of air
  * is only about \f$1\%\f$ of the viscosity of liquid water.) As a
- * consequence, the \f$\frac{k_{r\alpha}}{\mu_\alpha}\f$ term
- * typically is much larger for the gas phase than for the wetting
+ * consequence, the mobility (\f$\frac{k_{r}}{\mu}\f$) is
+ * typically much larger for the gas phase than for the wetting
  * phase. For this reason, the Richards model assumes that
- * \f$\frac{k_{rn}}{\mu_n}\f$ is infinitely large. This implies that
+ * gas phase mobility is infinitely large. This implies that
  * the pressure of the gas phase is equivalent to the static pressure
  * distribution and that therefore, mass conservation only needs to be
  * considered for the wetting phase.
@@ -70,9 +56,9 @@
  * saturation is calculated using the inverse of the capillary
  * pressure, i.e.
  \f[
- S_w = p_c^{-1}(p_n - p_w)
+ S_w = p_c^{-1}(p_g - p_w)
  \f]
  * holds, where \f$p_n\f$ is a given reference pressure. Nota bene,
  * that the last step is assumes that the capillary
  * pressure-saturation curve can be uniquely inverted, so it is not
  * possible to set the capillary pressure to zero when using the
@@ -70,9 +56,9 @@
  \f]
- * holds, where \f$p_n\f$ is a given reference pressure. Nota bene,
+ * holds, where \f$p_g\f$ is a given reference gas pressure. Nota bene,
  * that the last step is assumes that the capillary
  * pressure-saturation curve can be uniquely inverted, so it is not